@@ -22,7 +22,10 @@
 #include <QObject>
 #include <QColor>
 
-namespace Analitza { class Variables;}
+namespace Analitza {
+	class Variables;
+	class Expression;
+}
 
 class VariablesModel;
 class PluginsModel;
@@ -32,17 +35,24 @@ class AnalitzaWrapper;
 class KAlgebraMobile : public QObject
 {
 	Q_OBJECT
+	Q_PROPERTY(Analitza::Variables* variables READ variables NOTIFY variablesChanged)
 	public:
 		explicit KAlgebraMobile(QObject* parent=0);
 		
-		void displayPlugin(int plugin);
-		
 		static KAlgebraMobile* self();
-	
+		void notifyVariablesChanged() { variablesChanged(); }
+		
 	public slots:
 		FunctionsModel* functionsModel();
 		Analitza::Variables* variables() const;
-		QStringList addFunction(const QString& expression, const QString& name = QString(), const QColor& color = QColor(), double up = 0., double down = 0.);
+		QStringList addFunction(const QString& expression, double up = 0., double down = 0.);
+		
+	private slots:
+		void functionRemoved(const QString& name);
+		void functionModified(const QString& name, const Analitza::Expression& exp);
+		
+	signals:
+		void variablesChanged();
 		
 	private:
 		static KAlgebraMobile* s_self;
